from distutils.core import setup

setup(
    name = 'tnestlist',
    version = '1.3.0',
    py_modules = ['tnestlist'],
    author = 'mengtaoc',
    author_email = 'chentao623tmc@126.com',
    url = 'https://pypi.org/project/tnestlist',
    description = 'A simple printer of nested lists',
)
